@@ -6,8 +6,6 @@ import zlib
 from os import sep
 import gettext
 
-from hash import hash_file
-
 import gi
 gi.require_version('Peas', '1.0')
 gi.require_version('Gtk', '3.0')
@@ -16,6 +14,8 @@ from gi.repository import GLib, GObject # pylint: disable=wrong-import-position
 from gi.repository import Peas, Gtk, Gdk # pylint: disable=wrong-import-position,
 from gi.repository import Gio, Pango, Totem # pylint: disable=wrong-import-position,no-name-in-module
 
+from hash import hash_file # pylint: disable=wrong-import-position
+
 gettext.textdomain ("totem")
 
 D_ = gettext.dgettext
@@ -29,6 +29,7 @@ SUBTITLES_EXT = [
     "asc",
     "txt",
     "sub",
+    "vtt",
     "srt",
     "smi",
     "ssa",
@@ -251,7 +252,7 @@ class DownloadThread (threading.Thread):
 
 # OpenSubtitles.org API abstraction
 
-class OpenSubtitlesModel (object):
+class OpenSubtitlesModel:
     """
     This contains the logic of the opensubtitles service.
     """
@@ -260,7 +261,7 @@ class OpenSubtitlesModel (object):
         self._token = None
 
         try:
-            import locale
+            import locale # pylint: disable=import-outside-toplevel
             (language_code, _) = locale.getlocale ()
             self.lang = LANGUAGES[language_code.split ('_')[0]]
         except (ImportError, IndexError, AttributeError, KeyError):
@@ -335,8 +336,8 @@ class OpenSubtitlesModel (object):
             if result.get ('data'):
                 self._lock.release ()
                 return (result['data'], message)
-            else:
-                message = _(u'No results found.')
+
+            message = _(u'No results found.')
         else:
             message = log_in_message
 
@@ -422,13 +423,17 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
 
         self._append_menu ()
 
-        self._totem.connect ('file-opened', self.__on_totem__file_opened)
-        self._totem.connect ('file-closed', self.__on_totem__file_closed)
+        self._totem.connect ('file-opened', self.__on_totem__file_opened) # pylint: disable=no-member
+        self._totem.connect ('file-closed', self.__on_totem__file_closed) # pylint: disable=no-member
 
         # Obtain the ServerProxy and init the model
         server = xmlrpc.client.Server ('http://api.opensubtitles.org/xml-rpc')
         self._model = OpenSubtitlesModel (server)
 
+        mrl = self._totem.get_current_mrl ()
+        if mrl:
+            self.__on_totem__file_opened(self._totem, self._totem.get_current_mrl ())
+
     def do_deactivate (self):
         if self._dialog:
             self._dialog.destroy ()
@@ -540,8 +545,7 @@ class OpenSubtitles (GObject.Object, # pylint: disable=R0902
         current_file = Gio.file_new_for_uri (self._totem.get_current_mrl ()) # pylint: disable=no-member
         scheme = current_file.get_uri_scheme ()
 
-        if (scheme == 'dvd' or scheme == 'http' or
-            scheme == 'dvb' or scheme == 'vcd'):
+        if scheme in ('dvd', 'http', 'dvb', 'vcd'):
             return False
 
         return True
