@@ -38,24 +38,20 @@ struct BaconVideoWidgetPropertiesPrivate {
 	int time;
 };
 
-#define BACON_VIDEO_WIDGET_PROPERTIES_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), BACON_TYPE_VIDEO_WIDGET_PROPERTIES, BaconVideoWidgetPropertiesPrivate))
-
-G_DEFINE_TYPE (BaconVideoWidgetProperties, bacon_video_widget_properties, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (BaconVideoWidgetProperties, bacon_video_widget_properties, GTK_TYPE_BOX)
 
 static void
 bacon_video_widget_properties_class_init (BaconVideoWidgetPropertiesClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (BaconVideoWidgetPropertiesPrivate));
-
 	object_class->dispose = bacon_video_widget_properties_dispose;
 }
 
 static void
 bacon_video_widget_properties_init (BaconVideoWidgetProperties *props)
 {
-	props->priv = G_TYPE_INSTANCE_GET_PRIVATE (props, BACON_TYPE_VIDEO_WIDGET_PROPERTIES, BaconVideoWidgetPropertiesPrivate);
+	props->priv = bacon_video_widget_properties_get_instance_private (props);
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (props), GTK_ORIENTATION_VERTICAL);
 }
@@ -63,7 +59,7 @@ bacon_video_widget_properties_init (BaconVideoWidgetProperties *props)
 static void
 bacon_video_widget_properties_dispose (GObject *object)
 {
-	BaconVideoWidgetPropertiesPrivate *priv = BACON_VIDEO_WIDGET_PROPERTIES_GET_PRIVATE (object);
+	BaconVideoWidgetPropertiesPrivate *priv = BACON_VIDEO_WIDGET_PROPERTIES (object)->priv;
 
 	if (priv->xml != NULL)
 		g_object_unref (priv->xml);
@@ -163,11 +159,26 @@ time_to_string_text (gint64 msecs)
 
 	if (hour > 0)
 	{
-		/* 5 hours 2 minutes 12 seconds */
-		string = g_strdup_printf (C_("time", "%s %s %s"), hours, mins, secs);
+		if (min > 0 && sec > 0)
+		{
+			/* 5 hours 2 minutes 12 seconds */
+			string = g_strdup_printf (C_("hours minutes seconds", "%s %s %s"), hours, mins, secs);
+		} else if (min > 0) {
+			/* 5 hours 2 minutes */
+			string = g_strdup_printf (C_("hours minutes", "%s %s"), hours, mins);
+		} else {
+			/* 5 hours */
+			string = g_strdup_printf (C_("hours", "%s"), hours);
+		}
 	} else if (min > 0) {
-		/* 2 minutes 12 seconds */
-		string = g_strdup_printf (C_("time", "%s %s"), mins, secs);
+		if (sec > 0)
+		{
+			/* 2 minutes 12 seconds */
+			string = g_strdup_printf (C_("minutes seconds", "%s %s"), mins, secs);
+		} else {
+			/* 2 minutes */
+			string = g_strdup_printf (C_("minutes", "%s"), mins);
+		}
 	} else if (sec > 0) {
 		/* 10 seconds */
 		string = g_strdup (secs);
