@@ -53,6 +53,7 @@
 #define PAGE_SIZE             50
 #define SCROLL_GET_MORE_LIMIT 0.8
 #define MIN_DURATION          5
+#define MAX_DURATION          G_MAXINT
 
 /* casts are to shut gcc up */
 static const GtkTargetEntry target_table[] = {
@@ -66,6 +67,7 @@ struct _TotemGriloPrivate {
 
 	gboolean plugins_activated;
 
+	GrlSource *tracker_src;
 	GrlSource *local_metadata_src;
 	GrlSource *title_parsing_src;
 	GrlSource *metadata_store_src;
@@ -192,7 +194,7 @@ strv_has_prefix (const char * const *strv,
 }
 
 static gboolean
-source_is_blacklisted (GrlSource *source)
+source_is_blocked (GrlSource *source)
 {
 	const char *id;
 	const char * const sources[] = {
@@ -210,7 +212,7 @@ source_is_blacklisted (GrlSource *source)
 }
 
 static gboolean
-source_is_browse_blacklisted (GrlSource *source)
+source_is_browse_blocked (GrlSource *source)
 {
 	const char *id;
 	const char * const sources[] = {
@@ -226,7 +228,7 @@ source_is_browse_blacklisted (GrlSource *source)
 }
 
 static gboolean
-source_is_search_blacklisted (GrlSource *source)
+source_is_search_blocked (GrlSource *source)
 {
 	const char *id;
 	const char * const sources[] = {
@@ -246,6 +248,7 @@ source_is_recent (GrlSource *source)
 	const char *id;
 	const char * const sources[] = {
 		"grl-tracker-source",
+		"grl-tracker3-source",
 		"grl-optical-media",
 		"grl-bookmarks",
 		NULL
@@ -375,6 +378,12 @@ get_thumbnail_cb (GObject *source_object,
 	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 		goto out;
 
+	if (!thumbnail && GRL_IS_MEDIA (thumb_data->media)) {
+		g_debug ("Failed to get thumbnail for '%s': %s",
+			 grl_media_get_url (thumb_data->media),
+			 error->message);
+	}
+
 	path = gtk_tree_row_reference_get_path (thumb_data->reference);
 	if (!path)
 		goto out;
@@ -611,7 +620,8 @@ get_source_priority (GrlSource *source)
 		return 100;
 	if (g_str_equal (id, "grl-bookmarks"))
 		return 75;
-	if (g_str_equal (id, "grl-tracker-source"))
+	if (g_str_equal (id, "grl-tracker-source") ||
+	    g_str_equal (id, "grl-tracker3-source"))
 		return 50;
 	if (g_str_has_prefix (id, "grl-upnp-") ||
 	    g_str_has_prefix (id, "grl-dleyna-"))
@@ -752,7 +762,7 @@ browse (TotemGrilo   *self,
 		grl_operation_options_set_type_filter (default_options, GRL_TYPE_FILTER_VIDEO);
 	if (grl_caps_is_key_range_filter (caps, GRL_METADATA_KEY_DURATION))
 		grl_operation_options_set_key_range_filter (default_options,
-							    GRL_METADATA_KEY_DURATION, MIN_DURATION, NULL,
+							    GRL_METADATA_KEY_DURATION, MIN_DURATION, MAX_DURATION,
 							    NULL);
 
 	bud = g_slice_new0 (BrowseUserData);
@@ -813,12 +823,18 @@ search_cb (GrlSource    *source,
 
 	self = TOTEM_GRILO (user_data);
 
-	if (error != NULL &&
-	    g_error_matches (error,
-	                     GRL_CORE_ERROR,
-	                     GRL_CORE_ERROR_OPERATION_CANCELLED) == FALSE) {
-		window = totem_object_get_main_window (self->priv->totem);
-		totem_interface_error (_("Search Error"), error->message, window);
+	if (error != NULL) {
+		if (g_error_matches (error,
+	                             GRL_CORE_ERROR,
+	                             GRL_CORE_ERROR_OPERATION_CANCELLED)) {
+			g_application_unmark_busy (g_application_get_default ());
+			/* Don't zero out self->priv->search_id to avoid a race
+			 * condition with next search. Don't update thumbnails. */
+			return;
+		} else {
+			window = totem_object_get_main_window (self->priv->totem);
+			totem_interface_error (_("Search Error"), error->message, window);
+		}
 	}
 
 	if (media != NULL) {
@@ -840,7 +856,6 @@ search_cb (GrlSource    *source,
 	if (remaining == 0) {
 		g_application_unmark_busy (g_application_get_default ());
 		self->priv->search_id = 0;
-		gtk_widget_set_sensitive (self->priv->search_entry, TRUE);
 		update_search_thumbnails (self);
 	}
 }
@@ -877,7 +892,6 @@ search_more (TotemGrilo *self)
 
 	search_options = get_search_options (self);
 
-	gtk_widget_set_sensitive (self->priv->search_entry, FALSE);
 	self->priv->search_page++;
 	self->priv->search_remaining = PAGE_SIZE;
 
@@ -911,9 +925,10 @@ search (TotemGrilo  *self,
 	GrlSource   *source,
 	const gchar *text)
 {
+	g_clear_handle_id (&self->priv->search_id, grl_operation_cancel);
+
 	gtk_tree_store_clear (GTK_TREE_STORE (self->priv->search_results_model));
 //	g_hash_table_remove_all (self->priv->cache_thumbnails);
-	gtk_widget_set_sensitive (self->priv->search_entry, FALSE);
 	self->priv->search_source = source;
 	g_free (self->priv->search_text);
 	self->priv->search_text = g_strdup (text);
@@ -1160,11 +1175,16 @@ content_changed (TotemGrilo   *self,
 	for (i = 0; i < changed_medias->len; i++) {
 		GrlMedia *media = changed_medias->pdata[i];
 		GtkTreeIter *iter;
-		char *str;
+		g_autofree char *str;
 
 		str = grl_media_serialize (media);
+		if (!grl_media_is_video (media) &&
+		    !grl_media_is_container (media)) {
+			g_debug ("Ignoring content changes for %s", str);
+			continue;
+		}
+
 		g_debug ("About to change %s in the store", str);
-		g_free (str);
 
 		if (find_media (model, media, &iter)) {
 			update_media (GTK_TREE_STORE (model), iter, source, media);
@@ -1189,11 +1209,10 @@ content_removed (TotemGrilo   *self,
 	for (i = 0; i < changed_medias->len; i++) {
 		GrlMedia *media = changed_medias->pdata[i];
 		GtkTreeIter *iter;
-		char *str;
+		g_autofree char *str;
 
 		str = grl_media_serialize (media);
 		g_debug ("About to remove %s from the store", str);
-		g_free (str);
 
 		if (find_media (model, media, &iter)) {
 			gtk_tree_store_remove (GTK_TREE_STORE (model), iter);
@@ -1220,11 +1239,15 @@ content_added (TotemGrilo   *self,
 
 	for (i = 0; i < changed_medias->len; i++) {
 		GrlMedia *media = changed_medias->pdata[i];
-		char *str;
+		g_autofree char *str;
 
 		str = grl_media_serialize (media);
+		if (!grl_media_is_video (media) &&
+		    !grl_media_is_container (media)) {
+			g_debug ("Ignoring content added for %s", str);
+			continue;
+		}
 		g_debug ("About to add %s to the store", str);
-		g_free (str);
 
 		add_local_metadata (self, source, media);
 		add_media_to_model (GTK_TREE_STORE (model), NULL, source, media);
@@ -1277,11 +1300,14 @@ source_added_cb (GrlRegistry *registry,
 		self->priv->metadata_store_src = source;
 	else if (g_str_equal (id, "grl-bookmarks"))
 		self->priv->bookmarks_src = source;
+	else if (g_str_equal (id, "grl-tracker-source") ||
+		 g_str_equal (id, "grl-tracker3-source"))
+		self->priv->tracker_src = source;
 
 	if (self->priv->plugins_activated == FALSE)
 		return;
 
-	if (source_is_blacklisted (source) ||
+	if (source_is_blocked (source) ||
 	    source_is_forbidden (source) ||
 	    !(grl_source_get_supported_media (source) & GRL_MEDIA_TYPE_VIDEO)) {
 		grl_registry_unregister_source (registry,
@@ -1297,7 +1323,8 @@ source_added_cb (GrlRegistry *registry,
 	}
 
 	/* The local search source */
-	if (g_str_equal (id, "grl-tracker-source"))
+	if (g_str_equal (id, "grl-tracker-source") ||
+	    g_str_equal (id, "grl-tracker3-source"))
 		name = _("Local");
 	else
 		name = grl_source_get_name (source);
@@ -1312,7 +1339,7 @@ source_added_cb (GrlRegistry *registry,
 			/* https://gitlab.gnome.org/GNOME/grilo-plugins/merge_requests/29 */
 			if (g_str_equal (id, "grl-tracker-source") == FALSE)
 				monitor = TRUE;
-		} else if (!source_is_browse_blacklisted (source)) {
+		} else if (!source_is_browse_blocked (source)) {
 			const GdkPixbuf *icon;
 
 			icon = totem_grilo_get_channel_icon ();
@@ -1338,7 +1365,7 @@ source_added_cb (GrlRegistry *registry,
 		}
 	}
 	if ((ops & GRL_OP_SEARCH) &&
-	    !source_is_search_blacklisted (source)) {
+	    !source_is_search_blocked (source)) {
 		totem_search_entry_add_source (TOTEM_SEARCH_ENTRY (self->priv->search_entry),
 					       grl_source_get_id (source),
 					       name,
@@ -1454,12 +1481,6 @@ load_grilo_plugins (TotemGrilo *self)
 	}
 	g_strfreev (configs);
 
-	/* GStreamer does not support VCDs:
-	 * https://gitlab.freedesktop.org/gstreamer/gst-plugins-bad/merge_requests/203 */
-	config = grl_config_new ("grl-optical-media", NULL);
-	grl_config_set_string (config, "ignored-scheme", "vcd");
-	grl_registry_add_config (registry, config, NULL);
-
 	g_signal_connect (registry, "source-added",
 	                  G_CALLBACK (source_added_cb), self);
 	g_signal_connect (registry, "source-removed",
@@ -1951,7 +1972,7 @@ search_mode_changed (GObject          *gobject,
 		/* Try to guess which source should be used for search */
 		model = gd_main_view_get_model (GD_MAIN_VIEW (self->priv->browser));
 		if (model == self->priv->recent_sort_model) {
-			id = "grl-tracker-source";
+			id = grl_source_get_id (self->priv->tracker_src);
 			self->priv->last_page = g_strdup ("recent");
 		} else {
 			GtkTreeIter iter;
