@@ -168,7 +168,9 @@ void	totem_object_play			(TotemObject *totem);
 void	totem_object_stop			(TotemObject *totem);
 void	totem_object_play_pause			(TotemObject *totem);
 void	totem_object_pause			(TotemObject *totem);
+gboolean totem_object_can_seek_next		(TotemObject *totem);
 void	totem_object_seek_next			(TotemObject *totem);
+gboolean totem_object_can_seek_previous		(TotemObject *totem);
 void	totem_object_seek_previous		(TotemObject *totem);
 void	totem_object_seek_time			(TotemObject *totem, gint64 msec, gboolean accurate);
 void	totem_object_seek_relative		(TotemObject *totem, gint64 offset, gboolean accurate);
@@ -191,6 +193,9 @@ GMenu *totem_object_get_menu_section		(TotemObject *totem,
 void totem_object_empty_menu_section		(TotemObject *totem,
 						 const char  *id);
 
+float		totem_object_get_rate		(TotemObject *totem);
+gboolean	totem_object_set_rate		(TotemObject *totem, float rate);
+
 GtkWidget *totem_object_get_video_widget	(TotemObject *totem);
 
 /* Database handling */
